# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools
Nesse curso é ensinado como contribuir co projeto de código aberto
Suportada versão 3 de Python.

[![Build Status](https://app.travis-ci.com/javanurbieta/libpythonpro.svg?branch=main)](https://app.travis-ci.com/javanurbieta/libpythonpro)

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt```

Pra conferir qualidade de código:
```console
flake8
```

Tópicos a serem abordados:
1. Git
2. Vitualenv
3. Pip
4. 